#!/usr/bin/env python

import os
from configargparse import ArgumentParser


def check(args):
    """
    Validates the existence of the input files and the output directory.

    Parameters
    ----------
    args : Namespace
        The arguments parsed from the command line, containing input file paths and output directory.

    Raises
    ------
    FileNotFoundError
        If either of the input files or the output directory does not exist.
    """
    # Confirm that both input files exist
    if not os.path.exists(args.input_path_1):
        raise FileNotFoundError(f"The file from the first input does not exist {args.input_path_1}.")
    if not os.path.exists(args.input_path_2):
        raise FileNotFoundError(f"The file from the second input does not exist {args.input_path_2}.")
    # Confirm that the output directory exists
    if not os.path.isdir(args.output_path):
        raise FileNotFoundError(f"The output directory does not exist {args.output_path}.")


def read_arguments():
    """
    Parses and validates the command line arguments.

    Returns
    -------
    Namespace
        The parsed arguments containing input file paths, output directory, and optional output file name.
    """
    parser = ArgumentParser(description='Process files')

    # Define the inputs (-i and -g) and the output (-o)
    parser.add_argument("-i", "--input1", "input_path_1", type=str, required=True,
                        help="The path of the first input file")
    parser.add_argument("-g", "--input2", "input_path_2", type=str, required=True,
                        help="The path of the second input file")
    parser.add_argument("-o", "--output", "output_path", type=str, required=True,
                        help="The path of the output directory")
    parser.add_argument("-n", "--doc_name", type=str, required=False,
                        help="The name of the output file (optional)")

    args = parser.parse_args()
    check(args)

    return args

